<?php
/*
Plugin Name: Global Script Manager
Description: Adds custom fields to insert content into head and body tags globally and per page.
Version: 1.0
Author: Zinavo
Author URI: https://www.zinavo.com/
View Tutorial: https://youtu.be/yeg3eRqjKMg
*/


// Add a custom link to the plugin row meta
add_filter('plugin_row_meta', 'gsm_add_plugin_row_meta', 10, 2);

function gsm_add_plugin_row_meta($links, $file) {
    if ($file == plugin_basename(__FILE__)) {
        $links[] = '<a href="https://www.zinavo.com/zinavo-global-script-manager.html" target="_blank" rel="noopener noreferrer">View details</a>';
        $links[] = '<a href="https://www.zinavo.com/wp-content/uploads/2024/12/Zinavo_Documentation-for-Global-Script-Manager-WordPress-Plugin.pdf" target="_blank" rel="noopener noreferrer">Documentation</a>';
        $links[] = '<a href="https://youtu.be/yeg3eRqjKMg" target="_blank" rel="noopener noreferrer">Video Tutorials</a>';
    }
    return $links;
}

// Add meta box to posts, pages, and products
function add_script_meta_box() {
    $screens = ['post', 'page', 'product'];
    foreach ($screens as $screen) {
        add_meta_box(
            'script_meta_box',
            'Custom Scripts',
            'script_meta_box_html',
            $screen,
            'normal',
            'high'
        );
    }
}
add_action('add_meta_boxes', 'add_script_meta_box');

// Create meta box HTML
function script_meta_box_html($post) {
    $head_value = get_post_meta($post->ID, '_head_script', true);
    $body_value = get_post_meta($post->ID, '_body_script', true);
    ?>
    <h4>Head Script</h4>
    <textarea name="head_script" id="head_script" rows="10" style="width: 100%;"><?php echo esc_textarea($head_value); ?></textarea>
    <p class="description">Enter the script to add after the head tag.</p>
    
    <h4>Body Script</h4>
    <textarea name="body_script" id="body_script" rows="10" style="width: 100%;"><?php echo esc_textarea($body_value); ?></textarea>
    <p class="description">Enter the script to add after the body tag.</p>
    <?php
}

// Save meta box data
function save_script_meta_box($post_id) {
    $allowed_tags = array(
        'script' => array(
            'type' => array(),
            'src' => array(),
            'async' => array(),
            'defer' => array()
        ),
        'meta' => array(
            'name' => array(),
            'content' => array()
        ),
        'link' => array(
            'rel' => array(),
            'href' => array(),
            'type' => array()
        ),
        'style' => array(),
        'noscript' => array()
    );

    if (array_key_exists('head_script', $_POST)) {
        update_post_meta(
            $post_id,
            '_head_script',
            wp_kses($_POST['head_script'], $allowed_tags)
        );
    }
    
    if (array_key_exists('body_script', $_POST)) {
        update_post_meta(
            $post_id,
            '_body_script',
            wp_kses($_POST['body_script'], $allowed_tags)
        );
    }
}
add_action('save_post', 'save_script_meta_box');

// Add scripts to head and body
function add_custom_scripts() {
    if (is_singular()) {
        $post_id = get_the_ID();
        $head_script = get_post_meta($post_id, '_head_script', true);
        $body_script = get_post_meta($post_id, '_body_script', true);
        
        if (!empty($head_script)) {
            add_action('wp_head', function() use ($head_script) {
                echo $head_script;
            }, 99);
        }
        
        if (!empty($body_script)) {
            add_action('wp_body_open', function() use ($body_script) {
                echo $body_script;
            }, 99);
        }
    }
}
add_action('wp', 'add_custom_scripts');

// Add settings page
function script_settings_menu() {
    add_options_page(
        'Global Script Settings',
        'Global Script Settings',
        'manage_options',
        'global-script-settings',
        'script_settings_page'
    );
}
add_action('admin_menu', 'script_settings_menu');

// Create settings page
function script_settings_page() {
    ?>
    <div class="wrap">
        <h1>Global Script Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('global_script_settings');
            do_settings_sections('global-script-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function script_register_settings() {
    register_setting('global_script_settings', 'global_head_script');
    register_setting('global_script_settings', 'global_body_script');
    
    add_settings_section(
        'global_script_settings_section',
        'Global Scripts',
        'script_settings_section_callback',
        'global-script-settings'
    );
    
    add_settings_field(
        'global_head_script',
        'Global Head Script',
        'global_head_script_callback',
        'global-script-settings',
        'global_script_settings_section'
    );
    
    add_settings_field(
        'global_body_script',
        'Global Body Script',
        'global_body_script_callback',
        'global-script-settings',
        'global_script_settings_section'
    );
}
add_action('admin_init', 'script_register_settings');

function script_settings_section_callback() {
    echo '<p>Add scripts that will appear after the head and body tags on all pages.</p>';
}

function global_head_script_callback() {
    $value = get_option('global_head_script');
    ?>
    <textarea name="global_head_script" rows="10" style="width: 100%;"><?php echo esc_textarea($value); ?></textarea>
    <p class="description">This script will be added after the head tag on all pages.</p>
    <?php
}

function global_body_script_callback() {
    $value = get_option('global_body_script');
    ?>
    <textarea name="global_body_script" rows="10" style="width: 100%;"><?php echo esc_textarea($value); ?></textarea>
    <p class="description">This script will be added after the body tag on all pages.</p>
    <?php
}

// Add global scripts
function add_global_scripts() {
    $global_head_script = get_option('global_head_script');
    $global_body_script = get_option('global_body_script');
    
    if (!empty($global_head_script)) {
        add_action('wp_head', function() use ($global_head_script) {
            echo $global_head_script;
        }, 98);
    }
    
    if (!empty($global_body_script)) {
        add_action('wp_body_open', function() use ($global_body_script) {
            echo $global_body_script;
        }, 98);
    }
}
add_action('wp', 'add_global_scripts');